<?php

class WPML_Tester {
    
    function __construct(){
        $this->admin_notices();
        $this->install();
        
        add_action( 'init', array( $this, 'init' ) );
        
        if( isset( $_POST['theme_translate'] ) || isset( $_POST['theme_update_translations'] ) ){
            $theme_context = (isset($_POST['theme_context'])) ? $_POST['theme_context'] : null;
            $theme_languages = (isset($_POST['theme_languages'])) ? $_POST['theme_languages'] : null;
            $theme_prefix = (isset($_POST['theme_prefix'])) ? $_POST['theme_prefix'] : null;
            
            if( !$theme_languages ){
                add_action( 'admin_notices', array( $this, 'no_selected_language_notice' ) );
            }
            
            if( !$theme_prefix ){
                add_action( 'admin_notices', array( $this, 'no_prefix_notice' ) );
            }
            
            if( !$theme_languages || !$theme_prefix ){
                return false;
            }
            
            update_option( 'WPML_tester_themes_prefix', $theme_prefix );
           
            if( isset( $_POST['theme_translate'] ) ){
                $this->translate_strings( $theme_context, $theme_languages, $theme_prefix );
                add_action( 'admin_notices', array( $this, 'strings_translated_notice' ) );
            } else {
                $this->update_strings( $theme_context, $theme_languages, $theme_prefix );
                add_action( 'admin_notices', array( $this, 'strings_updated_notice' ) );
            }
        }
        
        if( isset( $_POST['plugin_translate'] ) || isset( $_POST['plugin_update_translations'] ) ){
            $plugin_context = (isset($_POST['plugin_context'])) ? $_POST['plugin_context'] : null;
            $plugin_languages = (isset($_POST['plugin_languages'])) ? $_POST['plugin_languages'] : null;
            $plugin_prefix = (isset($_POST['plugin_prefix'])) ? $_POST['plugin_prefix'] : null;
            
            if( !$plugin_languages ){
                add_action( 'admin_notices', array( $this, 'no_selected_language_notice' ) );
            }
            
            if( !$plugin_prefix ){
                add_action( 'admin_notices', array( $this, 'no_prefix_notice' ) );
            }
            
            if( !$plugin_languages || !$plugin_prefix ){
                return false;
            }
            
            update_option( 'WPML_tester_plugins_prefix', $plugin_prefix );

            if( isset( $_POST['plugin_translate'] ) ){
                $this->translate_strings( $plugin_context, $plugin_languages, $plugin_prefix );
                add_action( 'admin_notices', array( $this, 'strings_translated_notice' ) );
            } else {
                $this->update_strings( $plugin_context, $plugin_languages, $plugin_prefix );
                add_action( 'admin_notices', array( $this, 'strings_updated_notice' ) );
            }
        }
        
        if( isset( $_POST['create_pages'] ) ){
            $page_languages = (isset($_POST['page_languages'])) ? $_POST['page_languages'] : null;
            
             if( !$page_languages ){
                add_action( 'admin_notices', array( $this, 'no_selected_language_for_pages_notice' ) );
                
                return false;
            }
            
            $this->create_dummy_pages( $page_languages );
            
            add_action( 'admin_notices', array( $this, 'pages_created_notice' ) );
        }
        
        if( isset( $_POST['scan'] ) ){ 
            
            add_action( 'admin_notices', array( $this, 'scanned_notice' ) );
            
        }
    }
    
    function admin_notices(){
        if( !defined( 'ICL_SITEPRESS_VERSION' ) || ICL_PLUGIN_INACTIVE ){
            if( !function_exists( 'is_multisite' ) || !is_multisite() ){
                add_action( 'admin_notices', array( $this, 'no_wpml_notice' ) );
            }
            
            return false;
        }
    }
    
    function init(){
	add_action('admin_menu', array($this, 'register_administration_page'));
    }
    
    function install(){
        if( get_option( 'WPML_tester_plugin ') === false ){
            add_option( 'WPML_tester_plugin', '1' );
        
            if( get_option( 'WPML_tester_themes_prefix ') === false ){
                add_option( 'WPML_tester_themes_prefix', 'WPML_' );
            }
        
            if( get_option( 'WPML_tester_plugins_prefix ') === false ){
                add_option( 'WPML_tester_plugins_prefix', 'WPML_' );
            }
        } 
    }
    
    function no_wpml_notice(){
    ?>
        <div class="message error"><p><?php printf( __('WPML Tester is enabled but not effective. It requires <a href="%s">WPML</a> in order to work.', 'wpml-tester'), 
                'http://wpml.org/' ); ?></p></div>
    <?php
    }
    
    function no_selected_language_notice(){
        echo '<div class="message error"><p>'. __('At least one language should be selected in order to translate strings.', 'wpml-tester') .'</p></div>';
    }
    
    function no_selected_language_for_pages_notice(){
        echo '<div class="message error"><p>'. __('At least one language should be selected in order to create pages with dummy content.', 'wpml-tester') .'</p></div>';
    }
    
    function no_prefix_notice(){
        echo '<div class="message error"><p>'. __('Prefix is required.', 'wpml-tester') .'</p></div>';
    }
    
    function strings_translated_notice(){
        echo '<div class="updated message fade"><p>'. __('Strings translated.', 'wpml-tester') .'</p></div>';
    }
    
    function strings_updated_notice(){
        echo '<div class="updated message fade"><p>'. __('Strings updated.', 'wpml-tester') .'</p></div>';
    }
    
    function pages_created_notice(){
        echo '<div class="updated message fade"><p>'. __('Pages created.', 'wpml-tester') .'</p></div>';
    }
    
    function scanned_notice(){
        echo '<div class="updated message fade"><p>'. __('Scan completed.', 'wpml-tester') .'</p></div>';
    }
    
    function register_administration_page() {		
	add_menu_page( __('Multilingual Compatibility Testing Tool', 'wpml-tester' ), __('WPML Tester', 'wpml-tester'), 'manage_options', 'wpml-tester', array($this, 'administration_page'),
	ICL_PLUGIN_URL . '/res/img/icon16.png');
    }
    
    function administration_page(){
        include( WPML_TESTER_MENUS_PATH . 'administration.php' );
    }
    
    function translate_strings( $context, $languages, $prefix ){
        global $wpdb;
        
        $strings = $wpdb->get_results( "SELECT id, language, context, value FROM ". $wpdb->prefix ."icl_strings" );
        
        if( $context !== 'all_themes' && $context !== 'all_plugins' ){
            foreach( $strings as $k => $v ){
                if( $context === $v->context ){
                    foreach( $languages as $k => $lang ){
                        $string_id = $v->id;
                        $translation = $prefix . $v->value;
                        
                        $is_string_translated = $wpdb->get_var( $wpdb->prepare( "SELECT id FROM ". $wpdb->prefix ."icl_string_translations WHERE string_id = %d AND language = %s", $string_id, $lang ) );

                        if( $is_string_translated == false ){
                            $data_to_insert = array(
                                'string_id' => $string_id,
                                'language'  => $lang,
                                'status'    => 1,
                                'value'     => $translation,
                                'translator_id'     => 1
                            );

                            $wpdb->insert( $wpdb->prefix ."icl_string_translations", $data_to_insert );
                        }
                    }
                }
            }
        } else {
            foreach( $strings as $k => $v ){
                foreach( $languages as $k => $lang ){
                    $string_id = $v->id;
                    $translation = $prefix . $v->value;
					
                    $is_string_translated = $wpdb->get_var( $wpdb->prepare( "SELECT id FROM ". $wpdb->prefix ."icl_string_translations WHERE string_id = %d AND language = %s", $string_id, $lang ) );
                    
                    if( $is_string_translated == false ){
					
                        $data_to_insert = array(
                            'string_id' => $string_id,
                            'language'  => $lang,
                            'status'    => 1,
                            'value'     => $translation,
                            'translator_id'     => 1
                        );
						
						$wpdb->insert( $wpdb->prefix ."icl_string_translations", $data_to_insert );
                    }
                }
            }
        }
    }
    
    function update_strings( $context, $languages, $prefix ){
        global $wpdb;
        
        $strings = $wpdb->get_results( "SELECT id, language, context, value FROM ". $wpdb->prefix ."icl_strings" );
        
        if( $context !== 'all_themes' && $context !== 'all_plugins'){
            foreach( $strings as $k => $v ){
                if( $context === $v->context ){
                    foreach( $languages as $k => $lang ){
                        $string_id = $v->id;
                        $translation = $prefix . $v->value;
                        
                        $is_string_translated = $wpdb->get_var( $wpdb->prepare( "SELECT id FROM ". $wpdb->prefix ."icl_string_translations WHERE string_id = %d AND language = %s", $string_id, $lang ) );
                        
                        if( $is_string_translated != false ){
                            $data_to_update = array(
                                'status'    => 1,
                                'value'     => $translation,
                                'translator_id'     => 1
                             );
                            
                            $wpdb->update( $wpdb->prefix ."icl_string_translations", $data_to_update, array( 'string_id' => $string_id, 'language' => $lang ) );
                        }
                    }
                }
            }
        } else {
            foreach( $strings as $k => $v ){
                foreach( $languages as $k => $lang ){
                    $string_id = $v->id;
                    $translation = $prefix . $v->value;
                        
                    $is_string_translated = $wpdb->get_var( $wpdb->prepare( "SELECT id FROM ". $wpdb->prefix ."icl_string_translations WHERE string_id = %d AND language = %s", $string_id, $lang ) );
                    
                    if( $is_string_translated != false ){
					
                        $data_to_update = array(
                            'status'    => 1,
                            'value'     => $translation,
                            'translator_id'     => 1
                        );
                            
                      $wpdb->update( $wpdb->prefix ."icl_string_translations", $data_to_update, array( 'string_id' => $string_id, 'language' => $lang ) );
                    }
                }
            } 
        }
    }
    
    function create_dummy_pages( $page_languages ){
            global $sitepress;
            
            foreach( $page_languages as $k => $lang ){
                
                $post_title = __('Page ', 'wpml-tester') . strtoupper( $lang );
                $post_content = __('This page is in language: '). strtoupper( $lang ) . __('Lorem ipsum dolor sit amet, consectetur adipiscing elit. 
                    Integer ac elit ligula, a dictum tellus. Etiam lacinia, odio placerat fermentum malesuada, 
                    purus quam dignissim arcu, et porta nisi orci et lectus. Morbi justo nulla, sagittis sit amet gravida nec, 
                    pharetra eget metus. Quisque malesuada velit ut est porta laoreet. Maecenas aliquam dolor eget nibh rhoncus fringilla. 
                    Praesent vehicula dapibus tincidunt. In et est ipsum, ut laoreet magna. Integer nulla sem, gravida id sollicitudin vel, 
                    hendrerit eget ante. 
                    <br />
                    Maecenas lobortis, turpis a ultricies ornare, dui urna facilisis leo, ac egestas tellus turpis ut felis. 
                    Aliquam eu turpis a magna feugiat venenatis vel quis leo. Sed nec ligula justo, eu elementum ipsum. 
                    Morbi malesuada dictum tempor. Cras lorem leo, sodales vitae ultrices et, placerat et tortor. 
                    Vivamus vel justo odio, sed pretium velit. Morbi non laoreet nisi. 
                    Cum sociis natoque penatibus et magnis dis parturient montes, nascetur ridiculus mus. 
                    Quisque odio eros, ultricies ac accumsan sit amet, varius eget est. 
                    Praesent feugiat lacinia ante sed varius. Curabitur varius ligula eu elit lacinia a semper metus vestibulum. 
                    Maecenas justo mauris, tempus nec pulvinar eget, euismod non lorem. Fusce vehicula bibendum mi in scelerisque. 
                    Vestibulum ante ipsum primis in faucibus orci luctus et ultrices posuere cubilia Curae; 
                    Praesent a augue ut nulla dignissim suscipit et vitae velit. Nullam consectetur dapibus nisl, a suscipit enim vestibulum at. 
                    <br />
                    Vivamus quis orci erat. Morbi varius ullamcorper tortor, quis facilisis elit sodales eget. Mauris a elit quam, quis viverra velit. 
                    Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos himenaeos. Quisque placerat rutrum vehicula. 
                    In a urna a massa ullamcorper sagittis. Maecenas ac lacinia ipsum. Nullam in leo sapien. Nulla sed pulvinar ipsum. 
                    Mauris a quam a justo suscipit vulputate. Vivamus nec metus purus. Cras sollicitudin, dolor sit amet consequat commodo, 
                    mauris nulla hendrerit orci, quis pharetra lacus elit at urna. Vivamus non metus vel turpis placerat eleifend. 
                    Proin sit amet risus nec justo varius accumsan ut sit amet eros. Sed pulvinar urna ut dolor rutrum rutrum. 
                    Maecenas commodo placerat dui, id pulvinar magna sodales non.', 'wpml-tester');
                
                $post_data = array(
                    'post_title' => $post_title,
                    'post_content' => $post_content,
                    'post_status' => 'publish',
                    'post_author' => 1
                 );
                
                $default_language = $sitepress->get_default_language();
                
                $post_id = wp_insert_post( $post_data );
                
                /*$data_to_insert = array(
                                'element_type' => 'post_page',
                                'element_id'  => $post_id,
                                'trid'    => 0,
                                'language_code'     => $lang,
                                'source_language_code'     => $default_language
                            );

                $wpdb->insert( $wpdb->prefix ."icl_translations", $data_to_insert );*/

            }
    }
    
    
    function scan(){
        
        
        
        
    }
    
    
}


?>